========
Examples
========

Start by importing UBCS LCP auxiliary package library.

.. code-block:: python

    import ubcs_auxiliary

Fitting 1D Gaussian
----------------------------

.. code-block:: python

    import ubcs_auxiliary


#    .. plot:: ./examples_py/numerical_bin_data.py
#           :include-source:
